@@ -1,6 +1,6 @@
 import datetime
 import json
-import six
+
 import pytz
 
 """
@@ -14,11 +14,12 @@ DATE_FORMAT = "%Y-%m-%d"
 
 def _datetime_encoder(obj):
     if isinstance(obj, datetime.datetime):
-        if obj.utcoffset() is None:  # support for <= 3.3
+        if obj.utcoffset() is None:  # 3.5
             obj = pytz.utc.localize(obj)
         return datetime.datetime.strftime(obj.astimezone(pytz.utc), DATETIME_FORMAT)
     if isinstance(obj, datetime.date):
         return datetime.datetime.strftime(obj, DATE_FORMAT)
+    return None
 
 
 def _datetime_decoder(dict_):
@@ -30,7 +31,7 @@ def _datetime_decoder(dict_):
             dict_[key] = ""
             continue
 
-        if value is not None and isinstance(value, six.string_types):
+        if value is not None and isinstance(value, str):
             try:
                 # The api always returns times like this
                 # 2014-07-25T09:12:24.735
